import { shallowMount } from '@vue/test-utils';
import Component from '@/components/JSONGroup.vue';

const factory = (data = {}, props = {}) => {
  const options = {
    data: () => ({ ...data }),
    propsData: { ...props },
  };

  return shallowMount(Component, options);
};

describe('Group Render', () => {
  it('depth of 0 should return top level props and next level array', () => {
    const wrapper = factory({}, {
      data: {
        'top-level-prop': 'test',
        'sketch-fab-model.background': '658ef1b171d7414884da95465879389b',
        'sketch-fab-model.id': '#273583',
      },
      depth: 0,
      currentSection: '',
    });

    expect(wrapper.vm.inputsToRender).toEqual({
      'top-level-prop': 'test',
    });

    expect(wrapper.vm.nextLevel).toEqual([
      'sketch-fab-model',
    ]);
  });

  it('should correctly render out the current levels data', () => {
    const wrapper = factory({}, {
      data: {
        'get-social.products.0.image.desktop': 'https://jdsports...',
        'get-social.products.0.image.mobile': 'https://jdsports...',
        'get-social.products.0.url': '/product/brown-adidas-originals-pod-s31/1188721',
        'get-social.products.1.image.desktop': 'https://jdsports...',
        'get-social.products.1.image.mobile': 'https://jdsports...',
        'get-social.products.1.url': '/product/black-adidas-originals-pod-s31/1189124',
        'get-social.titles.headline': 'Get Social',
        'get-social.titles.subtext': '#Creator',
        'get-social.url': 'Follow Us',
        'get-socialBreak': 'should not appear',
        'something-else.with.get-social.prop': 'should not appear',
      },
      depth: 1,
      currentSection: 'get-social',
    });

    expect(wrapper.vm.inputsToRender).toEqual({
      'get-social.url': 'Follow Us',
    });

    expect(wrapper.vm.nextLevel).toEqual([
      'get-social.products',
      'get-social.titles',
    ]);

    wrapper.setProps({ depth: 2 });

    expect(wrapper.vm.inputsToRender).toEqual({
      'get-social.titles.headline': 'Get Social',
      'get-social.titles.subtext': '#Creator',
    });
  });

  it('should indicate when current depth is an array', () => {
    const wrapper = factory({}, {
      data: {
        'get-social.products.0.image.desktop': 'https://jdsports...',
        'get-social.products.0.image.mobile': 'https://jdsports...',
        'get-social.products.0.url': '/product/brown-adidas-originals-pod-s31/1188721',
        'get-social.products.1.image.desktop': 'https://jdsports...',
        'get-social.products.1.image.mobile': 'https://jdsports...',
        'get-social.products.1.url': '/product/black-adidas-originals-pod-s31/1189124',
        'get-social.titles.headline': 'Get Social',
        'get-social.titles.subtext': '#Creator',
        'get-social.url': 'Follow Us',
        'get-socialBreak': 'should not appear',
      },
      depth: 2,
      currentSection: 'get-social.products',
    });

    expect(wrapper.vm.isArray).toBe(true);
  });

  it('generate a readable title from the current section', () => {
    const wrapper = factory({}, {
      data: {},
      currentSection: '0.content.extra-video.normal.image',
    });
    expect(wrapper.vm.readableTitle).toBe('content extra video normal image');

    wrapper.setProps({ currentSection: 'content.extra-video.normal.0.image' });
    expect(wrapper.vm.readableTitle).toBe('content extra video normal 0 image');

    wrapper.setProps({ currentSection: '0' });
    expect(wrapper.vm.readableTitle).toBe('section');
  });
});
