import { shallowMount } from '@vue/test-utils';
import Component from '@/components/JSONInput.vue';

const factory = (data = {}, props = {}) => {
  const options = {
    data: () => ({ ...data }),
    propsData: { ...props },
  };

  return shallowMount(Component, options);
};

describe('JD Input', () => {
  it('should render a label with input', () => {
    const wrapper = factory();

    expect(wrapper.find('label').exists()).toBe(true);
    expect(wrapper.find('input').exists()).toBe(true);
  });

  it('should render a readable label from an object path', () => {
    const wrapper = factory({}, {
      label: 'colourways.modal.template.0.component',
    });

    expect(wrapper.find('label').text()).toBe('component');

    wrapper.setProps({ label: 'textColor' });

    expect(wrapper.find('label').text()).toBe('text Color');
  });

  it('should display a textarea when value contains line breaks', () => {
    const wrapper = factory({}, {
      value: 'text with line break\nin it',
    });

    expect(wrapper.find('textarea').exists()).toBe(true);
  });
});
